@@ -10,12 +10,16 @@
     clippy::needless_pass_by_value,
     clippy::new_without_default,
     clippy::pedantic,
+    clippy::redundant_feature_names,
     clippy::redundant_pub_crate,
     clippy::too_many_arguments,
     clippy::too_many_lines,
+    clippy::transmute_undefined_repr,
     clippy::unused_self,
+    clippy::use_self,
     clippy::used_underscore_binding,
     clippy::wildcard_dependencies,
+    clippy::wrong_self_convention,
     clippy::zero_ptr
 )]
 
@@ -27,6 +31,7 @@ mod constant_wrapper;
 mod graphics_wrapper;
 mod image_wrapper;
 mod input_wrapper;
+mod math_wrapper;
 mod music_wrapper;
 mod resource_wrapper;
 mod sound_wrapper;
@@ -46,6 +51,7 @@ use crate::constant_wrapper::add_module_constants;
 use crate::graphics_wrapper::add_graphics_functions;
 use crate::image_wrapper::add_image_class;
 use crate::input_wrapper::add_input_functions;
+use crate::math_wrapper::add_math_functions;
 use crate::music_wrapper::add_music_class;
 use crate::resource_wrapper::add_resource_functions;
 use crate::sound_wrapper::add_sound_class;
@@ -89,6 +95,7 @@ fn pyxel_wrapper(_py: Python, m: &PyModule) -> PyResult<()> {
     add_input_functions(m)?;
     add_graphics_functions(m)?;
     add_audio_functions(m)?;
+    add_math_functions(m)?;
 
     Ok(())
 }
